@@ -253,6 +253,7 @@ typedef struct _MHW_KERNEL_PARAM
     void    *pExtra;                         //!< Kernel parameter
     uint8_t *pBinary;                        //!< Pointer to kernel binary
     int32_t iSize;                          //!< Kernel size
+    int32_t iPaddingSize;                   //!< Padding size  
     int32_t iGrfCount;                      //!< Number of registers
     int32_t iBTCount;                       //!< Number of BT entries
     int32_t iThreadCount;                   //!< Number of threads (max)
@@ -451,6 +452,7 @@ typedef struct _MHW_ID_ENTRY_PARAMS
     int32_t             iCrsThdConDataRdLn;             //!
     PMHW_STATE_HEAP     pGeneralStateHeap;              //! General state heap in use
     MemoryBlock         *memoryBlock;                   //! Memory block associated with the state heap
+    uint32_t            preferredSlmAllocationSize;     //! SLM Allocation Size for per SubSlice
 } MHW_ID_ENTRY_PARAMS, *PMHW_ID_ENTRY_PARAMS;
 
 typedef struct _MHW_PLANE_SETTING
@@ -844,6 +846,7 @@ struct MHW_STATE_HEAP_SETTINGS
     HeapManager::Behavior m_dshBehavior = HeapManager::Behavior::wait;    //!< DSH behavior
 
     uint32_t        dwNumSyncTags = 0; //!< to be removed with old interfaces
+    MOS_HW_RESOURCE_DEF m_heapUsageType = MOS_CODEC_RESOURCE_USAGE_BEGIN_CODEC;
 };
 
 typedef struct _MHW_STATE_HEAP_DYNAMIC_ALLOC_PARAMS
