@@ -184,6 +184,14 @@ enum VpKernelID
     // mediacopy-render copy
     kernelRenderCopy,
 
+    kernelOclFcCommon,
+    kernelOclFcFP,
+    kernelOclFc444PL3Input,
+    kernelOclFc444PL3Output,
+    kernelOclFc420PL3Input,
+    kernelOclFc420PL3Output,
+    kernelOclFc422HVInput,
+
     baseKernelMaxNumID
 };
 
@@ -191,10 +199,26 @@ enum VpKernelIDNext
 {
     vpKernelIDNextBase = 0x200,
     kernelHdr3DLutCalc = vpKernelIDNextBase,
+    kernelHdr3DLutCalcOcl,
     kernelHVSCalc,
+
+    // AI Common
+    kernelAiCommon,
+    kernelAiCommonEnd = kernelAiCommon + 0x1000,
+
     vpKernelIDNextMax
 };
 
+//!
+//! \brief Base VP graph list
+//!
+enum VP_GRAPH_ID
+{
+    VP_GRAPH_ID_INVALID = 0,
+
+    VP_GRAPH_ID_BASE_MAX
+};
+
 typedef struct _VPHAL_COMPOSITE_CACHE_CNTL
 {
     bool                        bL3CachingEnabled;
@@ -389,6 +413,9 @@ C_ASSERT(VPHAL_GAMMA_Count == 5);  //!< When adding, update assert
 #define IS_COLOR_SPACE_BT2020_RGB(_a) (_a == CSpace_BT2020_RGB || \
                                        _a == CSpace_BT2020_stRGB)
 
+#define IS_COLOR_SPACE_BT709_RGB(_a) (_a == CSpace_sRGB || \
+                                      _a == CSpace_stRGB)
+
 //!
 //! \def IS_COLOR_SPACE_BT2020(_a)
 //! Check if the color space is BT2020
@@ -397,6 +424,12 @@ C_ASSERT(VPHAL_GAMMA_Count == 5);  //!< When adding, update assert
                                    IS_COLOR_SPACE_BT2020_RGB(_a))
 
 //!
+//! \def IS_COLOR_SPACE_RGB(_a)
+//! Check if the color space is RGB
+//!
+#define IS_COLOR_SPACE_RGB(_a) (IS_COLOR_SPACE_BT2020_RGB(_a) || \
+                                IS_COLOR_SPACE_BT709_RGB(_a))
+//!
 //! \brief Sample Type enum
 //!
 typedef enum _VPHAL_SAMPLE_TYPE
@@ -534,7 +567,8 @@ typedef enum _VPHAL_OUTPUT_PIPE_MODE
     VPHAL_OUTPUT_PIPE_MODE_INVALID = -1,  //!< None output pipe selected. This is an invalid state
     VPHAL_OUTPUT_PIPE_MODE_COMP    = 0,   //!< Composition output pipe. RenderTarget will be written by Composition
     VPHAL_OUTPUT_PIPE_MODE_SFC     = 1,   //!< SFC output pipe. RenderTarget will be written by SFC
-    VPHAL_OUTPUT_PIPE_MODE_VEBOX   = 2    //!< Vebox output pipe. RenderTarget will be written by Vebox
+    VPHAL_OUTPUT_PIPE_MODE_VEBOX   = 2,    //!< Vebox output pipe. RenderTarget will be written by Vebox
+    VPHAL_OUTPUT_PIPE_MODE_NPU     = 3
 } VPHAL_OUTPUT_PIPE_MODE,
     *PVPHAL_OUTPUT_PIPE_MODE;
 
@@ -900,6 +934,7 @@ typedef struct _VPHAL_3DLUT_PARAMS
     uint32_t       ChannelMapping     = 0;        // Channel Mapping for the 3DLUT input to 3DLUT output.
     uint16_t       BitDepthPerChannel = 0;        // Bit Depth Per Channel(4 channels for 3DLUT).
     uint16_t       ByteCountPerEntry  = 0;        // Byte Count Per Entry including reserved bytes.
+    uint16_t       MappingMode        = 0;        // Mapping Mode
 
     VPHAL_3DLUT_INTERPOLATION InterpolationMethod = VPHAL_3DLUT_INTERPOLATION_DEFAULT;  // VEBox 3DLut interpolation mode
 } VPHAL_3DLUT_PARAMS, *PVPHAL_3DLUT_PARAMS;
@@ -931,6 +966,14 @@ typedef struct _VPHAL_NLAS_PARAMS
     float fNonLinearCrop;
 } VPHAL_NLAS_PARAMS, *PVPHAL_NLAS_PARAMS;
 
+typedef struct _VPHAL_VIDEO_COLOR_RGBA
+{
+    float R;
+    float G;
+    float B;
+    float A;
+} VPHAL_VIDEO_COLOR_RGBA;
+
 //!
 //! Structure VPHAL_COLORFILL_PARAMS
 //! \brief ColorFill parameters
@@ -939,6 +982,7 @@ typedef struct _VPHAL_COLORFILL_PARAMS
 {
     bool         bYCbCr                 = false;
     uint32_t     Color                  = 0;
+    VPHAL_VIDEO_COLOR_RGBA Color1       = {};
     VPHAL_CSPACE CSpace                 = CSpace_None;
     bool         bDisableColorfillinSFC = false;
     bool         bOnePixelBiasinSFC     = false;
@@ -1049,6 +1093,8 @@ struct VPHAL_RENDER_PARAMS
 
     bool bForceToRender = false;  // Force to render to perform scaling.
 
+    HANDLE gpuAppTaskEvent;  //!< GPU App task event
+
     VPHAL_RENDER_PARAMS() : uSrcCount(0),
                             pSrc(),
                             uDstCount(0),
@@ -1071,7 +1117,8 @@ struct VPHAL_RENDER_PARAMS
                             pExtensionData(nullptr),
                             bPathKernel(false),
                             bUseVEHdrSfc(false),
-                            bNonFirstFrame(false)
+                            bNonFirstFrame(false),
+                            gpuAppTaskEvent(nullptr)
     {
     }
 };
