@@ -93,7 +93,8 @@ public:
                     // free all allocated surfaces
                     while (i > 0)
                     {
-                        MOS_FreeMemAndSetNull(TempOutputSurfaces[--i]);
+                        --i;
+                        MOS_FreeMemAndSetNull(TempOutputSurfaces[i]);
                     }
                     return MOS_STATUS_NO_SPACE;
                 }
@@ -320,7 +321,7 @@ public:
 
     // External components
     PMOS_INTERFACE              m_pOsInterface;
-    PRENDERHAL_INTERFACE        m_pRenderHal;
+    PRENDERHAL_INTERFACE_LEGACY m_pRenderHal;
 
 protected:
     // External tables
@@ -342,6 +343,9 @@ protected:
     // Status Buffer, Video Pre-Processing Only
     STATUS_TABLE_UPDATE_PARAMS  m_StatusTableUpdateParams = { 0 };
 
+    // Media user setting instance
+    MediaUserSettingSharedPtr m_userSettingPtr = nullptr;
+
 };
 
 #endif // __VPHAL_RENDER_RENDERSTATE_H__
