@@ -175,6 +175,15 @@ public:
     //!
     uint32_t   GetGpuStatusTag() { return m_GPUStatusTag; }
 
+    //!
+    //! \brief    Get i915 ctx
+    //! \param    [in] ctxNodeIndex
+    //!           ctx index in array
+    //! \return   MOS_LINUX_CONTEXT
+    //!           mos linux ctx in array of ctxNodeIndex
+    //!
+    MOS_LINUX_CONTEXT* GetI915Context(uint32_t ctxNodeIndex){return ctxNodeIndex < (MAX_ENGINE_INSTANCE_NUM+1) ?  m_i915Context[ctxNodeIndex] : nullptr;}
+
     //!
     //! \brief    Increment GPU status tag
     //!
@@ -253,7 +262,7 @@ private:
 
     //! \brief    Flag to indicate current command buffer flused or not, if not
     //!           re-use it
-    volatile bool m_cmdBufFlushed;
+    volatile bool m_cmdBufFlushed = false;
 
     //! \brief    internal back up for in-use command buffer
     PMOS_COMMAND_BUFFER m_commandBuffer = nullptr;
@@ -283,7 +292,7 @@ private:
     OsContext *m_osContext = nullptr;
 
     MOS_GPUCTX_CREATOPTIONS_ENHANCED *m_createOptionEnhanced = nullptr;
-    MOS_LINUX_CONTEXT*  m_i915Context[MAX_ENGINE_INSTANCE_NUM+1];
+    MOS_LINUX_CONTEXT*  m_i915Context[MAX_ENGINE_INSTANCE_NUM+1] = {};
     uint32_t     m_i915ExecFlag = 0;
 
 #if (_DEBUG || _RELEASE_INTERNAL)
