@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2018-2022, Intel Corporation
+* Copyright (c) 2018-2025, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -94,6 +94,28 @@ MOS_STATUS EncodeBasicFeature::Init(void *setting)
         MediaUserSetting::Group::Sequence);
     m_enableTileStitchByHW = outValue.Get<bool>();
 
+
+    if (m_osInterface != nullptr)
+    {
+        //If Wa_16025947269 is set, disable chroma prefetch
+        MEDIA_WA_TABLE *waTable = m_osInterface->pfnGetWaTable(m_osInterface);
+        m_chromaPrefetchDisable = (waTable != nullptr) ? MEDIA_IS_WA(waTable, Wa_16025947269) : false;
+
+        //If user setting is set, set m_chromaPrefetchDisable as the user setting value.
+#if (_DEBUG || _RELEASE_INTERNAL)
+        bool chromaPrefetchDisable = 0;
+        auto status = ReadUserSettingForDebug(
+            m_userSettingPtr,
+            chromaPrefetchDisable,
+            "ChromaPrefetchDisable",
+            MediaUserSetting::Group::Sequence);
+        if (status == MOS_STATUS_SUCCESS)
+        {
+            m_chromaPrefetchDisable = chromaPrefetchDisable;
+        }
+#endif
+    }
+
     return MOS_STATUS_SUCCESS;
 }
 
@@ -196,7 +218,28 @@ MOS_STATUS EncodeBasicFeature::Update(void *params)
     }
 
     // check output Chroma format
-    UpdateFormat(params);
+    ENCODE_CHK_STATUS_RETURN(UpdateFormat(params));
+
+    m_predicationNotEqualZero              = encodeParams->m_predicationNotEqualZero;
+    m_predicationEnabled                   = encodeParams->m_predicationEnabled;
+    m_setMarkerEnabled                     = encodeParams->m_setMarkerEnabled;
+    m_predicationResOffset                 = encodeParams->m_predicationResOffset;
+    m_presPredication                      = encodeParams->m_presPredication;
+    m_tempPredicationBuffer                = encodeParams->m_tempPredicationBuffer;
+
+    if (m_predicationBuffer == nullptr && m_predicationEnabled)
+    {
+        // initiate allocation parameters and lock flags
+        MOS_ALLOC_GFXRES_PARAMS allocParamsForBufferLinear;
+        MOS_ZeroMemory(&allocParamsForBufferLinear, sizeof(MOS_ALLOC_GFXRES_PARAMS));
+        allocParamsForBufferLinear.Type         = MOS_GFXRES_BUFFER;
+        allocParamsForBufferLinear.TileType     = MOS_TILE_LINEAR;
+        allocParamsForBufferLinear.Format       = Format_Buffer;
+        allocParamsForBufferLinear.ResUsageType = MOS_HW_RESOURCE_USAGE_ENCODE_INTERNAL_READ_WRITE_CACHE;
+        allocParamsForBufferLinear.dwBytes      = sizeof(uint32_t);
+        allocParamsForBufferLinear.pBufName     = "PredicationBuffer";
+        m_predicationBuffer                     = m_allocator->AllocateResource(allocParamsForBufferLinear, false);
+    }
 
     return MOS_STATUS_SUCCESS;
 }
