@@ -64,8 +64,7 @@ struct MHW_VFE_SCOREBOARD
 struct MHW_HEAPS_RESOURCE
 {
     PMOS_RESOURCE          presInstructionBuffer = nullptr;
-    PMHW_INLINE_DATA_PARAMS inlineDataParamsBase   = nullptr;
-    uint32_t                inlineDataParamSize   = 0;
+    uint64_t               kernelStartGfxAddress = 0;
 };
 
 enum MHW_VFE_SLICE_DISABLE
