@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2022-2023, Intel Corporation
+* Copyright (c) 2022-2025, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -254,6 +254,15 @@ MOS_STATUS MosUserSetting::InitMosCommonUserSetting(MediaUserSettingSharedPtr us
         true,
         USER_SETTING_CONFIG_PERF_PATH);  //"Perf Profiler Merge by Header Support."
 
+    DeclareUserSettingKey(
+        userSettingPtr,
+        __MEDIA_USER_FEATURE_VALUE_PERF_PROFILER_PARALLEL_EXEC,
+        MediaUserSetting::Group::Device,
+        false,
+        true,
+        true,
+        USER_SETTING_CONFIG_PERF_PATH); //"Perf Profiler Parallel Execution Support."
+
     DeclareUserSettingKey(
         userSettingPtr,
         __MEDIA_USER_FEATURE_VALUE_PERF_PROFILER_OUTPUT_FILE_NAME,
@@ -1138,6 +1147,13 @@ MOS_STATUS MosUserSetting::InitUserSettingForDebug(MediaUserSettingSharedPtr use
         true,
         USER_SETTING_CONFIG_PERMANENT_PATH);//"If enabled, specify this is in pre-si simulation/emulation mode."
 
+    DeclareUserSettingKeyForDebug(
+        userSettingPtr,
+        __MEDIA_USER_FEATURE_VALUE_ENABLE_VDBOX_ID_REPORT,
+        MediaUserSetting::Group::Device,
+        0,
+        true); //"Enable Vdbox physical engine id report"
+
     DeclareUserSettingKeyForDebug(
         userSettingPtr,
         __MEDIA_USER_FEATURE_VALUE_FORCE_VDBOX,
@@ -1152,6 +1168,13 @@ MOS_STATUS MosUserSetting::InitUserSettingForDebug(MediaUserSettingSharedPtr use
         0,
         true); //"Force the VEBox to be used. (Default 0: FORCE_VEBOX_NONE )"
 
+    DeclareUserSettingKeyForDebug(
+        userSettingPtr,
+        __MEDIA_USER_FEATURE_VALUE_USED_VDBOX_ID,
+        MediaUserSetting::Group::Device,
+        0,
+        true); //"Used Vdbox physical id. (Default 0: Not used, Each Hex symbol represents one VDBOX, e.g. bits[3:0] means VD0, bits[7:4] means VD1)"
+
     DeclareUserSettingKeyForDebug(
         userSettingPtr,
         __MEDIA_USER_FEATURE_VALUE_FORCE_YFYS,
@@ -1481,6 +1504,20 @@ MOS_STATUS MosUserSetting::InitUserSettingForDebug(MediaUserSettingSharedPtr use
         MediaUserSetting::Group::Device,
         0,
         true);
+
+    DeclareUserSettingKeyForDebug(
+        userSettingPtr,
+        "ForceTargetUsage",
+        MediaUserSetting::Group::Sequence,
+        uint32_t(0),
+        false);
+
+    DeclareUserSettingKeyForDebug(
+        userSettingPtr,
+        "ChromaPrefetchDisable",
+        MediaUserSetting::Group::Sequence,
+        uint32_t(0), // 0 chroma prefetch enabled, 1 chroma prefetch disabled ;
+        false);
     return MOS_STATUS_SUCCESS;
 }
 
