@@ -77,6 +77,7 @@ public:
         bool               decompForInterlacedSurfWaEnabled = false;
         bool               enableSFCLinearOutputByTileConvert = false;
         bool               fallbackScalingToRender8K          = false;
+        uint64_t           hybridMgrSubmitMode                = 0;
     };
 
     uint32_t Is3DLutKernelOnly()
@@ -225,6 +226,11 @@ public:
         return m_ctrlVal.splitFramePortions;
     }
 
+    uint64_t GetHybridMgrSubmitMode()
+    {
+        return m_ctrlVal.hybridMgrSubmitMode;
+    }
+
     MOS_STATUS ForceRenderPath(bool status)
     {
         m_ctrlVal.disableSfc                = status;
