@@ -56,6 +56,22 @@ public:
     //!
     ~GpuContextSpecificNext();
 
+    //!
+    //! \brief    Static entrypoint, get the gpu context object
+    //! \param    [in] gpuNode
+    //!           Gpu node
+    //! \param    [in] cmdBufMgr
+    //!           Command buffer manager
+    //! \param    [in] reusedContext
+    //!           Reused gpu context
+    //! \return   GpuContextNext*
+    //!           the os specific object for gpu context
+    //!
+    static GpuContextNext* Create(
+        const MOS_GPU_NODE gpuNode,
+        CmdBufMgrNext      *cmdBufMgr,
+        GpuContextNext     *reusedContext);
+
     //!
     //! \brief    Initialize gpu context
     //! \details  Linux specific initialize for gpu context
@@ -68,7 +84,7 @@ public:
     //! \return   MOS_STATUS
     //!           Return MOS_STATUS_SUCCESS if successful, otherwise failed
     //!
-    MOS_STATUS Init(OsContextNext *osContext,
+    virtual MOS_STATUS Init(OsContextNext *osContext,
                     MOS_STREAM_HANDLE streamState,
                     PMOS_GPUCTX_CREATOPTIONS createOption);
 
@@ -182,6 +198,15 @@ public:
     //!
     uint32_t   GetGpuStatusTag() { return m_GPUStatusTag; }
 
+    //!
+    //! \brief    Get i915 ctx
+    //! \param    [in] ctxNodeIndex
+    //!           ctx index in array
+    //! \return   MOS_LINUX_CONTEXT
+    //!           mos linux ctx in array of ctxNodeIndex
+    //!
+    MOS_LINUX_CONTEXT* GetI915Context(uint32_t ctxNodeIndex){return ctxNodeIndex < (MAX_ENGINE_INSTANCE_NUM+1) ?  m_i915Context[ctxNodeIndex] : nullptr;}
+
     //!
     //! \brief    Increment GPU status tag
     //!
@@ -195,7 +220,7 @@ public:
     //!             priority to set for current workload.
     //! \return void
     //!
-    void UpdatePriority(int32_t priority);
+    virtual void UpdatePriority(int32_t priority);
 
     //!
     //! \brief    Allocate gpu status buffer for gpu sync
@@ -210,12 +235,41 @@ public:
     //!
     void StoreCreateOptions(PMOS_GPUCTX_CREATOPTIONS createoption);
 
+    //!
+    //! \brief    Get Oca RTLog resource instance on GPU Context.
+    //! \return   PMOS_RESOURCE
+    //!
+    PMOS_RESOURCE GetOcaRTLogResource(PMOS_RESOURCE globalInst);
+
 #if MOS_COMMAND_RESINFO_DUMP_SUPPORTED
     void                PushCmdResPtr(const void *p) { m_cmdResPtrs.push_back(p); }
     void                ClearCmdResPtrs() { m_cmdResPtrs.clear(); }
     const std::vector<const void *> &GetCmdResPtrs() const { return m_cmdResPtrs; }
 #endif // MOS_COMMAND_RESINFO_DUMP_SUPPORTED
 protected:
+    virtual MOS_STATUS Init3DCtx(PMOS_CONTEXT osParameters,
+                PMOS_GPUCTX_CREATOPTIONS createOption,
+                unsigned int *nengine,
+                void *engine_map);
+
+    virtual MOS_STATUS InitComputeCtx(PMOS_CONTEXT osParameters,
+                unsigned int *nengine,
+                void *engine_map,
+                MOS_GPU_NODE gpuNode,
+                bool *isEngineSelectEnable);
+
+    virtual MOS_STATUS InitVdVeCtx(PMOS_CONTEXT osParameters,
+                MOS_STREAM_HANDLE streamState,
+                PMOS_GPUCTX_CREATOPTIONS createOption,
+                unsigned int *nengine,
+                void *engine_map,
+                MOS_GPU_NODE gpuNode,
+                bool *isEngineSelectEnable);
+
+    virtual MOS_STATUS InitBltCtx(PMOS_CONTEXT osParameters,
+                unsigned int *nengine,
+                void *engine_map);
+
     //!
     //! \brief    Map resources with aux plane to aux table
     //! \return   MOS_STATUS
@@ -247,7 +301,7 @@ protected:
     //! \return   int32_t
     //!           Return 0 if successful, otherwise error code
     //!
-    int32_t ParallelSubmitCommands(std::map<uint32_t, PMOS_COMMAND_BUFFER> secondaryCmdBufs,
+    virtual int32_t ParallelSubmitCommands(std::map<uint32_t, PMOS_COMMAND_BUFFER> secondaryCmdBufs,
                                    PMOS_CONTEXT osContext,
                                    uint32_t execFlag,
                                    int32_t dr4);
@@ -260,8 +314,8 @@ protected:
         PMOS_GPUCTX_CREATOPTIONS option,
         __u64 &caps);
 
-    MOS_STATUS ReportEngineInfo(
-        struct i915_engine_class_instance *engineMap,
+    virtual MOS_STATUS ReportEngineInfo(
+        void *engine_map,
         int engineNum, bool engineSelectEnable = false);
 
     MOS_STATUS ReportMemoryInfo(
@@ -271,13 +325,18 @@ protected:
     MOS_LINUX_BO* GetNopCommandBuffer(
         MOS_STREAM_HANDLE streamState);
 
-    bool SelectEngineInstanceByUser(struct i915_engine_class_instance *engineMap,
+    virtual bool SelectEngineInstanceByUser(void *engine_map,
         uint32_t *engineNum, uint32_t userEngineInstance, MOS_GPU_NODE gpuNode);
 #endif // _DEBUG || _RELEASE_INTERNAL
 
     void UnlockPendingOcaBuffers(PMOS_COMMAND_BUFFER cmdBuffer, PMOS_CONTEXT mosContext);
 
-private:
+    virtual MOS_GPU_COMPONENT_ID GetGpuComponentId()
+    {
+        return MOS_GPU_COMPONENT_DEFAULT;
+    }
+
+protected:
     //! \brief    internal command buffer pool per gpu context
     std::vector<CommandBufferNext *> m_cmdBufPool;
 
@@ -292,7 +351,7 @@ private:
 
     //! \brief    Flag to indicate current command buffer flused or not, if not
     //!           re-use it
-    volatile bool m_cmdBufFlushed;
+    volatile bool m_cmdBufFlushed = false;
 
     //! \brief    internal back up for in-use command buffer
     PMOS_COMMAND_BUFFER m_commandBuffer = nullptr;
@@ -330,12 +389,20 @@ private:
                                                                         //!< false if using MOS_GPUCTX_CREATOPTIONS
     bool                             m_bProtectedContext    = false;    //!< false if clear GEM context is created as protected or not
 
-    MOS_LINUX_CONTEXT*  m_i915Context[MAX_ENGINE_INSTANCE_NUM+1];
+    MOS_LINUX_CONTEXT*  m_i915Context[MAX_ENGINE_INSTANCE_NUM+1] = {};
     uint32_t     m_i915ExecFlag = 0;
     int32_t      m_currCtxPriority = 0;
     bool m_ocaLogSectionSupported = true;
     // bool m_ocaSizeIncreaseDone = false;
 
+    bool m_ocaRtLogResInited = false;
+    MOS_RESOURCE m_ocaRtLogResource = {};
+    //! \brief Recreate GEM Context
+    //! \return   MOS_STATUS
+    //!           Return MOS_STATUS_SUCCESS if successful, otherwise error code
+    //!
+    MOS_STATUS RecreateContext(bool bIsProtected, MOS_STREAM_HANDLE streamState);
+
 #if (_DEBUG || _RELEASE_INTERNAL)
     /*!\brief bits(23...16), (15...8), (7...0) are for Compute, VEbox and VDbox ;
     single or multi engine instance can be selected at same time(0x10103 to select Compute1, VE1, VD1&VD2 for example)*/
