@@ -42,8 +42,6 @@ static pthread_mutex_t command_dump_mutex = PTHREAD_MUTEX_INITIALIZER;
 GpuContextSpecificNextXe::~GpuContextSpecificNextXe()
 {
     MOS_OS_FUNCTION_ENTER;
-
-    Clear();
 }
 
 MOS_STATUS GpuContextSpecificNextXe::Init3DCtx(PMOS_CONTEXT osParameters,
@@ -226,6 +224,11 @@ MOS_STATUS GpuContextSpecificNextXe::InitBltCtx(PMOS_CONTEXT osParameters,
         return MOS_STATUS_UNKNOWN;
     }
     numPlacement = *nengine;
+    if (numPlacement >= 2)
+    {
+        // only use BCS0. BCS8 is paging copy
+        numPlacement = 1;
+    }
 
     m_i915Context[0] = mos_context_create_shared(osParameters->bufmgr,
                                              nullptr,
@@ -245,11 +248,6 @@ MOS_STATUS GpuContextSpecificNextXe::InitBltCtx(PMOS_CONTEXT osParameters,
     return eStatus;
 }
 
-void GpuContextSpecificNextXe::Clear()
-{
-    MOS_OS_FUNCTION_ENTER;
-}
-
 MOS_STATUS GpuContextSpecificNextXe::PatchCommandBuffer(
     MOS_STREAM_HANDLE   streamState,
     PMOS_COMMAND_BUFFER cmdBuffer)
@@ -469,7 +467,15 @@ MOS_STATUS GpuContextSpecificNextXe::SubmitCommandBuffer(
                 m_secondaryCmdBufs[0] = cmdBuffer;
                 cmdBufMapIsReused = true;
             }
-
+#if (_DEBUG || _RELEASE_INTERNAL)
+            // Dump CmdBuffer in trace before submit
+            auto  it = m_secondaryCmdBufs.begin();
+            while(it != m_secondaryCmdBufs.end())
+            {
+                MOS_TraceDumpExt("CmdBuffer", m_gpuContext, it->second->pCmdBase, it->second->iOffset);
+                it++;
+            }
+#endif
             ret = ParallelSubmitCommands(m_secondaryCmdBufs,
                                  perStreamParameters,
                                  execFlag,
@@ -589,20 +595,6 @@ void GpuContextSpecificNextXe::UpdatePriority(int32_t priority)
     //Note: need to implement this bufmgr api to set exec queue property
 }
 
-#if (_DEBUG || _RELEASE_INTERNAL)
-//Note: combind these two functions in both class in furture
-bool GpuContextSpecificNextXe::SelectEngineInstanceByUser(void *engine_map,
-        uint32_t *engineNum, uint32_t userEngineInstance, MOS_GPU_NODE gpuNode)
-{
-    MOS_UNUSED(engine_map);
-    MOS_UNUSED(engineNum);
-    MOS_UNUSED(userEngineInstance);
-    MOS_UNUSED(gpuNode);
-    uint32_t engineInstance     = 0x0;
-    return engineInstance;
-}
-#endif
-
 MOS_STATUS GpuContextSpecificNextXe::ReportEngineInfo(
         void *engine_map,
         int engineNum, bool engineSelectEnable)
